@@ -347,10 +347,18 @@ class BaseBenchmark(ABC):
                     # Ensure that the model_id2label does not contain
                     # duplicates modulo synonyms
                     for idx, label in enumerate(model_id2label):
-                        canonical_syn = [syn_lst
-                                         for syn_lst in self.label_synonyms
-                                         if label in syn_lst][0][-1]
-                        model_id2label[idx] = canonical_syn
+                        try:
+                            canonical_syn = [syn_lst
+                                             for syn_lst in self.label_synonyms
+                                             if label in syn_lst][0][-1]
+                            model_id2label[idx] = canonical_syn
+
+                        # IndexError appears when the label does not appear
+                        # within the label_synonyms (i.e. that we added it in
+                        # the previous step). In this case, we just skip the
+                        # label.
+                        except IndexError:
+                            continue
 
                     # Get the synonyms of all the labels, new ones included
                     new_synonyms = self.label_synonyms
@@ -486,7 +494,11 @@ class BaseBenchmark(ABC):
                 subprocess.run(['pip3', 'install', url])
 
             # Load the model
-            model = spacy.load(local_model_id)
+            try:
+                model = spacy.load(local_model_id)
+            except OSError:
+                raise InvalidBenchmark(f'The model {model_id} could not '
+                                       f'be installed from spaCy.')
 
             return dict(model=model)
 
@@ -767,11 +779,6 @@ class BaseBenchmark(ABC):
             # Load the data collator
             data_collator = self._load_data_collator(tokenizer)
 
-            # Enable `transformers` verbosity to see a training
-            # progress bar
-            if progress_bar:
-                tf_logging.set_verbosity_warning()
-
             # Initialise training arguments
             training_args = TrainingArguments(
                 output_dir='.',
@@ -784,14 +791,15 @@ class BaseBenchmark(ABC):
                 per_device_eval_batch_size=32,
                 learning_rate=2e-5,
                 num_train_epochs=1000,
-                warmup_steps=(len(train) // 4),
+                warmup_steps=((len(train) * 0.9) // 32),
                 gradient_accumulation_steps=1,
                 load_best_model_at_end=True
             )
 
-            # Disable `transformers` verbosity again
-            if not self.verbose:
-                tf_logging.set_verbosity_error()
+            # Manually set `disable_tqdm` to `False` if `progress_bar` is
+            # `True`
+            if progress_bar:
+                training_args.disable_tqdm = False
 
             metrics = defaultdict(list)
             for _ in itr:
@@ -828,6 +836,9 @@ class BaseBenchmark(ABC):
                         else:
                             trainer = Trainer(**trainer_args)
 
+                        # Set transformers logging back to error
+                        tf_logging.set_verbosity_error()
+
                         # Remove the callback which prints the metrics after
                         # each evaluation
                         if not self.verbose:
